@@ -24,7 +24,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QFrame>
 #include <QTabWidget>
 
-class KIcon;
 
 namespace Gwenview {
 
@@ -54,6 +53,7 @@ class SideBarPage : public QWidget {
 	Q_OBJECT
 public:
 	SideBarPage(const QString& title);
+	~SideBarPage();
 	void addWidget(QWidget*);
 	void addStretch();
 
