@@ -115,11 +115,8 @@ void ThumbnailCache::queueThumbnail(const QString& path, const QImage& image) {
 
 void ThumbnailCache::run() {
 	QMutexLocker locker(&mMutex);
-	while (true) {
+	while (!mCache.isEmpty()) {
 		Cache::ConstIterator it = mCache.constBegin();
-		if (it == mCache.constEnd()) {
-			break;
-		}
 		const QString path = it.key();
 		const QImage image = it.value();
 
@@ -131,9 +128,6 @@ void ThumbnailCache::run() {
 		locker.relock();
 
 		mCache.remove(path);
-		if (mCache.isEmpty()) {
-			break;
-		}
 	}
 }
 
@@ -142,6 +136,11 @@ QImage ThumbnailCache::value(const QString& path) const {
 	return mCache.value(path);
 }
 
+bool ThumbnailCache::isEmpty() const {
+	QMutexLocker locker(&mMutex);
+	return mCache.isEmpty();
+}
+
 
 //------------------------------------------------------------------------
 //
@@ -704,4 +703,9 @@ void ThumbnailLoadJob::emitThumbnailLoadingFailed() {
 }
 
 
+bool ThumbnailLoadJob::isPendingThumbnailCacheEmpty() {
+	return sThumbnailCache->isEmpty();
+}
+
+
 } // namespace
