@@ -40,6 +40,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <kdebug.h>
 #include <kdirmodel.h>
 #include <kglobalsettings.h>
+#include <klineedit.h>
 #include <klocale.h>
 #include <kurl.h>
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
@@ -48,6 +49,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 // Local
 #include "archiveutils.h"
+#include "itemeditor.h"
 #include "paintutils.h"
 #include "thumbnailview.h"
 #include "timeutils.h"
@@ -636,7 +638,7 @@ struct PreviewItemDelegatePrivate {
 
 
 PreviewItemDelegate::PreviewItemDelegate(ThumbnailView* view)
-: QAbstractItemDelegate(view)
+: QItemDelegate(view)
 , d(new PreviewItemDelegatePrivate) {
 	d->that = this;
 	d->mView = view;
@@ -708,21 +710,27 @@ QSize PreviewItemDelegate::sizeHint( const QStyleOptionViewItem & /*option*/, co
 }
 
 
-bool PreviewItemDelegate::eventFilter(QObject*, QEvent* event) {
-	switch (event->type()) {
-	case QEvent::ToolTip:
-		return true;
+bool PreviewItemDelegate::eventFilter(QObject* object, QEvent* event) {
+	if (object == d->mView->viewport()) {
+		switch (event->type()) {
+		case QEvent::ToolTip:
+			return true;
 
-	case QEvent::HoverMove:
-	case QEvent::HoverLeave:
-		return d->hoverEventFilter(static_cast<QHoverEvent*>(event));
+		case QEvent::HoverMove:
+		case QEvent::HoverLeave:
+			return d->hoverEventFilter(static_cast<QHoverEvent*>(event));
 
-	case QEvent::MouseButtonPress:
-	case QEvent::MouseButtonRelease:
-		return d->mouseButtonEventFilter(event->type());
+		case QEvent::MouseButtonPress:
+		case QEvent::MouseButtonRelease:
+			return d->mouseButtonEventFilter(event->type());
 
-	default:
-		return false;
+		default:
+			return false;
+		}
+	} else {
+		// Necessary for the item editor to work correctly (especially closing
+		// the editor with the Escape key)
+		return QItemDelegate::eventFilter(object, event);
 	}
 }
 
@@ -956,4 +964,45 @@ void PreviewItemDelegate::slotRowsChanged() {
 }
 
 
+QWidget * PreviewItemDelegate::createEditor(QWidget* parent, const QStyleOptionViewItem& /*option*/, const QModelIndex& /*index*/) const {
+	return new ItemEditor(parent);
+}
+
+
+void PreviewItemDelegate::setEditorData(QWidget* widget, const QModelIndex& index) const {
+	ItemEditor* edit = qobject_cast<ItemEditor*>(widget);
+	if (!edit) {
+		return;
+	}
+	edit->setText(index.data().toString());
+}
+
+
+void PreviewItemDelegate::updateEditorGeometry(QWidget* widget, const QStyleOptionViewItem& option, const QModelIndex& index) const {
+	ItemEditor* edit = qobject_cast<ItemEditor*>(widget);
+	if (!edit) {
+		return;
+	}
+	QString text = index.data().toString();
+	int textWidth = edit->fontMetrics().width("  " + text + "  ");
+	QRect textRect(
+		option.rect.left() + (option.rect.width() - textWidth) / 2,
+		option.rect.top() + 2 * ITEM_MARGIN + d->mThumbnailSize,
+		textWidth,
+		edit->sizeHint().height());
+
+	edit->setGeometry(textRect);
+}
+
+
+void PreviewItemDelegate::setModelData(QWidget* widget, QAbstractItemModel* model, const QModelIndex& index) const {
+	ItemEditor* edit = qobject_cast<ItemEditor*>(widget);
+	if (!edit) {
+		return;
+	}
+	if (index.data().toString() != edit->text()) {
+		model->setData(index, edit->text(), Qt::EditRole);
+	}
+}
+
 } // namespace
