@@ -1,31 +1,35 @@
-/* ============================================================
+/** ===========================================================
+ * @file
  *
- * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * This file is a part of digiKam project
+ * <a href="http://www.digikam.org">http://www.digikam.org</a>
  *
- * Date        : 2006-09-13
- * Description : LibRaw settings widgets
+ * @date   2006-09-13
+ * @brief  LibRaw settings widgets
  *
- * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2007-2008 by Guillaume Castagnino <casta at xwing dot info>
+ * @author Copyright (C) 2006-2010 by Gilles Caulier
+ *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
+ * @author Copyright (C) 2006-2010 by Marcel Wiesweg
+ *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
+ * @author Copyright (C) 2007-2008 by Guillaume Castagnino
+ *         <a href="mailto:casta at xwing dot info">casta at xwing dot info</a>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
+ * either version 2, or (at your option)
+ * any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * ============================================================ */
 
-#include "dcrawsettingswidget.h"
 #include "dcrawsettingswidget.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QCheckBox>
 #include <QLabel>
@@ -33,7 +37,7 @@
 #include <QWhatsThis>
 #include <QToolTip>
 
-// KDE includes.
+// KDE includes
 
 #include <kapplication.h>
 #include <kdialog.h>
@@ -41,16 +45,17 @@
 #include <kurllabel.h>
 #include <ktoolinvocation.h>
 
-// Local includes.
+// Local includes
 
 #include "kdcraw.h"
 #include "rnuminput.h"
 #include "rcombobox.h"
+#include "rexpanderbox.h"
 
 namespace KDcrawIface
 {
 
-class DcrawSettingsWidgetPriv
+class DcrawSettingsWidget::DcrawSettingsWidgetPriv
 {
 public:
 
@@ -98,80 +103,70 @@ public:
         outIccUrlEdit                  = 0;
         inputColorSpaceLabel           = 0;
         inputColorSpaceComboBox        = 0;
+        fixColorsHighlights            = 0;
     }
 
-    QWidget         *demosaicingSettings;
-    QWidget         *whiteBalanceSettings;
-    QWidget         *correctionsSettings;
-    QWidget         *colormanSettings;
+    QWidget*         demosaicingSettings;
+    QWidget*         whiteBalanceSettings;
+    QWidget*         correctionsSettings;
+    QWidget*         colormanSettings;
 
-    QLabel          *whiteBalanceLabel;
-    QLabel          *customWhiteBalanceLabel;
-    QLabel          *customWhiteBalanceGreenLabel;
-    QLabel          *brightnessLabel;
-    QLabel          *RAWQualityLabel;
-    QLabel          *NRThresholdLabel;
-    QLabel          *caRedMultLabel;
-    QLabel          *caBlueMultLabel;
-    QLabel          *unclipColorLabel;
-    QLabel          *reconstructLabel;
-    QLabel          *inputColorSpaceLabel;
-    QLabel          *outputColorSpaceLabel;
-    QLabel          *medianFilterPassesLabel;
+    QLabel*          whiteBalanceLabel;
+    QLabel*          customWhiteBalanceLabel;
+    QLabel*          customWhiteBalanceGreenLabel;
+    QLabel*          brightnessLabel;
+    QLabel*          RAWQualityLabel;
+    QLabel*          NRThresholdLabel;
+    QLabel*          caRedMultLabel;
+    QLabel*          caBlueMultLabel;
+    QLabel*          unclipColorLabel;
+    QLabel*          reconstructLabel;
+    QLabel*          inputColorSpaceLabel;
+    QLabel*          outputColorSpaceLabel;
+    QLabel*          medianFilterPassesLabel;
 
-    QCheckBox       *blackPointCheckBox;
-    QCheckBox       *whitePointCheckBox;
-    QCheckBox       *sixteenBitsImage;
-    QCheckBox       *autoBrightnessBox;
-    QCheckBox       *fourColorCheckBox;
-    QCheckBox       *dontStretchPixelsCheckBox;
-    QCheckBox       *enableNoiseReduction;
-    QCheckBox       *enableCACorrection;
+    QCheckBox*       blackPointCheckBox;
+    QCheckBox*       whitePointCheckBox;
+    QCheckBox*       sixteenBitsImage;
+    QCheckBox*       autoBrightnessBox;
+    QCheckBox*       fourColorCheckBox;
+    QCheckBox*       dontStretchPixelsCheckBox;
+    QCheckBox*       enableNoiseReduction;
+    QCheckBox*       enableCACorrection;
+    QCheckBox*       fixColorsHighlights;
 
-    KUrlRequester   *inIccUrlEdit;
-    KUrlRequester   *outIccUrlEdit;
+    KUrlRequester*   inIccUrlEdit;
+    KUrlRequester*   outIccUrlEdit;
 
-    RComboBox       *whiteBalanceComboBox;
-    RComboBox       *RAWQualityComboBox;
-    RComboBox       *unclipColorComboBox;
-    RComboBox       *inputColorSpaceComboBox;
-    RComboBox       *outputColorSpaceComboBox;
+    RComboBox*       whiteBalanceComboBox;
+    RComboBox*       RAWQualityComboBox;
+    RComboBox*       unclipColorComboBox;
+    RComboBox*       inputColorSpaceComboBox;
+    RComboBox*       outputColorSpaceComboBox;
 
-    RIntNumInput    *customWhiteBalanceSpinBox;
-    RIntNumInput    *reconstructSpinBox;
-    RIntNumInput    *blackPointSpinBox;
-    RIntNumInput    *whitePointSpinBox;
-    RIntNumInput    *NRThresholdSpinBox;
-    RIntNumInput    *medianFilterPassesSpinBox;
+    RIntNumInput*    customWhiteBalanceSpinBox;
+    RIntNumInput*    reconstructSpinBox;
+    RIntNumInput*    blackPointSpinBox;
+    RIntNumInput*    whitePointSpinBox;
+    RIntNumInput*    NRThresholdSpinBox;
+    RIntNumInput*    medianFilterPassesSpinBox;
 
-    RDoubleNumInput *customWhiteBalanceGreenSpinBox;
-    RDoubleNumInput *caRedMultSpinBox;
-    RDoubleNumInput *caBlueMultSpinBox;
-    RDoubleNumInput *brightnessSpinBox;
+    RDoubleNumInput* customWhiteBalanceGreenSpinBox;
+    RDoubleNumInput* caRedMultSpinBox;
+    RDoubleNumInput* caBlueMultSpinBox;
+    RDoubleNumInput* brightnessSpinBox;
 };
 
-DcrawSettingsWidget::DcrawSettingsWidget(QWidget *parent, int advSettings)
-                   : QToolBox(parent), d(new DcrawSettingsWidgetPriv)
+DcrawSettingsWidget::DcrawSettingsWidget(QWidget* parent, int advSettings)
+                   : RExpanderBox(parent), d(new DcrawSettingsWidgetPriv)
 {
     setup(advSettings);
 }
 
-DcrawSettingsWidget::DcrawSettingsWidget(QWidget *parent, bool sixteenBitsOption,
-                                         bool outputColorSpaceOption,
-                                         bool postProcessingOptions)
-                   : QToolBox(parent), d(new DcrawSettingsWidgetPriv)
-{
-    int advSettings = 0;
-
-    if (sixteenBitsOption)      advSettings |= SIXTEENBITS;
-    if (outputColorSpaceOption) advSettings |= COLORSPACE;
-    if (postProcessingOptions)  advSettings |= POSTPROCESSING;
-
-    setup(advSettings);
-}
-
 void DcrawSettingsWidget::setup(int advSettings)
 {
+    setObjectName( QLatin1String("DCRawSettings Expander" ));
+
     // ---------------------------------------------------------------
     // DEMOSAICING Settings panel
 
@@ -273,9 +268,8 @@ void DcrawSettingsWidget::setup(int advSettings)
                                                      "interpolation to Red-Green and Blue-Green channels."));
     demosaicingLayout->addWidget(d->medianFilterPassesLabel,   line, 0, 1, 1);
     demosaicingLayout->addWidget(d->medianFilterPassesSpinBox, line, 1, 1, 2);
-    demosaicingLayout->setRowStretch(line + 1, 10);
 
-    insertItem(DEMOSAICING, d->demosaicingSettings, i18n("Demosaicing"));
+    addItem(d->demosaicingSettings, SmallIcon("kdcraw"), i18n("Demosaicing"), QString("demosaicing"), true);
 
     // ---------------------------------------------------------------
     // WHITE BALANCE Settings Panel
@@ -283,12 +277,12 @@ void DcrawSettingsWidget::setup(int advSettings)
     d->whiteBalanceSettings         = new QWidget(this);
     QGridLayout* whiteBalanceLayout = new QGridLayout(d->whiteBalanceSettings);
 
-    d->whiteBalanceLabel    = new QLabel(i18n("Method"), d->whiteBalanceSettings);
-    d->whiteBalanceComboBox = new RComboBox(d->whiteBalanceSettings);
+    d->whiteBalanceLabel            = new QLabel(i18n("Method:"), d->whiteBalanceSettings);
+    d->whiteBalanceComboBox         = new RComboBox(d->whiteBalanceSettings);
     d->whiteBalanceComboBox->insertItem(RawDecodingSettings::NONE,   i18n("Default D65"));
     d->whiteBalanceComboBox->insertItem(RawDecodingSettings::CAMERA, i18n("Camera"));
     d->whiteBalanceComboBox->insertItem(RawDecodingSettings::AUTO,   i18n("Automatic"));
-    d->whiteBalanceComboBox->insertItem(RawDecodingSettings::CUSTOM, i18n("Manual"));
+    d->whiteBalanceComboBox->insertItem(RawDecodingSettings::CUSTOM, i18nc("set white balance manually", "Manual"));
     d->whiteBalanceComboBox->setDefaultIndex(RawDecodingSettings::CAMERA);
     d->whiteBalanceComboBox->setWhatsThis(i18n("<p><b>White Balance</b><p>"
                                           "Configure the raw white balance:<p>"
@@ -341,6 +335,11 @@ void DcrawSettingsWidget::setup(int advSettings)
                                              "Specify the reconstruct highlight level. "
                                              "Low values favor whites and high values favor colors."));
 
+    d->fixColorsHighlights = new QCheckBox(i18n("Correct false colors in highlights"), d->whiteBalanceSettings);
+    d->fixColorsHighlights->setWhatsThis(i18n("<p>If enabled, images with overblown channels are processed much "
+                                              "more accurately, without 'pink clouds' (and blue highlights under "
+                                              "tungsten lamps)."));
+
     d->autoBrightnessBox = new QCheckBox(i18n("Auto Brightness"), d->whiteBalanceSettings);
     d->autoBrightnessBox->setWhatsThis(i18n("<p>If disable, use a fixed white level "
                                             "and ignore the image histogram to adjust brightness."));
@@ -350,7 +349,7 @@ void DcrawSettingsWidget::setup(int advSettings)
     d->brightnessSpinBox->setDecimals(2);
     d->brightnessSpinBox->setRange(0.0, 10.0, 0.01);
     d->brightnessSpinBox->setDefaultValue(1.0);
-    d->brightnessSpinBox->setWhatsThis(i18n("<p><b>Brighness</b><p>"
+    d->brightnessSpinBox->setWhatsThis(i18n("<p><b>Brightness</b><p>"
                                             "Specify the brightness level of output image."
                                             "The default value is 1.0 (works in 8-bit mode only).<p>"));
 
@@ -402,18 +401,18 @@ void DcrawSettingsWidget::setup(int advSettings)
     whiteBalanceLayout->addWidget(d->unclipColorComboBox,            3, 1, 1, 2);
     whiteBalanceLayout->addWidget(d->reconstructLabel,               4, 0, 1, 1);
     whiteBalanceLayout->addWidget(d->reconstructSpinBox,             4, 1, 1, 2);
-    whiteBalanceLayout->addWidget(d->autoBrightnessBox,              5, 0, 1, 2);
-    whiteBalanceLayout->addWidget(d->brightnessLabel,                6, 0, 1, 1);
-    whiteBalanceLayout->addWidget(d->brightnessSpinBox,              6, 1, 1, 2);
-    whiteBalanceLayout->addWidget(d->blackPointCheckBox,             7, 0, 1, 1);
-    whiteBalanceLayout->addWidget(d->blackPointSpinBox,              7, 1, 1, 2);
-    whiteBalanceLayout->addWidget(d->whitePointCheckBox,             8, 0, 1, 1);
-    whiteBalanceLayout->addWidget(d->whitePointSpinBox,              8, 1, 1, 2);
-    whiteBalanceLayout->setRowStretch(9, 10);
+    whiteBalanceLayout->addWidget(d->fixColorsHighlights,            5, 0, 1, 2);
+    whiteBalanceLayout->addWidget(d->autoBrightnessBox,              6, 0, 1, 2);
+    whiteBalanceLayout->addWidget(d->brightnessLabel,                7, 0, 1, 1);
+    whiteBalanceLayout->addWidget(d->brightnessSpinBox,              7, 1, 1, 2);
+    whiteBalanceLayout->addWidget(d->blackPointCheckBox,             8, 0, 1, 1);
+    whiteBalanceLayout->addWidget(d->blackPointSpinBox,              8, 1, 1, 2);
+    whiteBalanceLayout->addWidget(d->whitePointCheckBox,             9, 0, 1, 1);
+    whiteBalanceLayout->addWidget(d->whitePointSpinBox,              9, 1, 1, 2);
     whiteBalanceLayout->setSpacing(KDialog::spacingHint());
     whiteBalanceLayout->setMargin(KDialog::spacingHint());
 
-    insertItem(WHITEBALANCE, d->whiteBalanceSettings, i18n("White Balance"));
+    addItem(d->whiteBalanceSettings, SmallIcon("kdcraw"), i18n("White Balance"), QString("whitebalance"), true);
 
     // ---------------------------------------------------------------
     // CORRECTIONS Settings panel
@@ -421,7 +420,7 @@ void DcrawSettingsWidget::setup(int advSettings)
     d->correctionsSettings         = new QWidget(this);
     QGridLayout* correctionsLayout = new QGridLayout(d->correctionsSettings);
 
-    d->enableNoiseReduction = new QCheckBox(i18n("Enable noise reduction"), d->correctionsSettings);
+    d->enableNoiseReduction        = new QCheckBox(i18n("Enable noise reduction"), d->correctionsSettings);
     d->enableNoiseReduction->setWhatsThis(i18n("<p><b>Enable Noise Reduction</b><p>"
                      "Use wavelets to erase noise while preserving real detail.<p>"));
 
@@ -466,7 +465,7 @@ void DcrawSettingsWidget::setup(int advSettings)
     correctionsLayout->setSpacing(KDialog::spacingHint());
     correctionsLayout->setMargin(KDialog::spacingHint());
 
-    insertItem(CORRECTIONS, d->correctionsSettings, i18n("Corrections"));
+    addItem(d->correctionsSettings, SmallIcon("kdcraw"), i18n("Corrections"), QString("corrections"), false);
 
     // ---------------------------------------------------------------
     // COLOR MANAGEMENT Settings panel
@@ -474,11 +473,11 @@ void DcrawSettingsWidget::setup(int advSettings)
     d->colormanSettings         = new QWidget(this);
     QGridLayout* colormanLayout = new QGridLayout(d->colormanSettings);
 
-    d->inputColorSpaceLabel    = new QLabel(i18n("Camera Profile:"), d->colormanSettings);
-    d->inputColorSpaceComboBox = new RComboBox(d->colormanSettings);
-    d->inputColorSpaceComboBox->insertItem(RawDecodingSettings::NOINPUTCS,     i18n("None"));
-    d->inputColorSpaceComboBox->insertItem(RawDecodingSettings::EMBEDDED,      i18n("Embedded"));
-    d->inputColorSpaceComboBox->insertItem(RawDecodingSettings::CUSTOMINPUTCS, i18n("Custom"));
+    d->inputColorSpaceLabel     = new QLabel(i18n("Camera Profile:"), d->colormanSettings);
+    d->inputColorSpaceComboBox  = new RComboBox(d->colormanSettings);
+    d->inputColorSpaceComboBox->insertItem(RawDecodingSettings::NOINPUTCS,     i18nc("Camera Profile", "None"));
+    d->inputColorSpaceComboBox->insertItem(RawDecodingSettings::EMBEDDED,      i18nc("Camera Profile", "Embedded"));
+    d->inputColorSpaceComboBox->insertItem(RawDecodingSettings::CUSTOMINPUTCS, i18nc("Camera Profile", "Custom"));
     d->inputColorSpaceComboBox->setDefaultIndex(RawDecodingSettings::NOINPUTCS);
     d->inputColorSpaceComboBox->setWhatsThis(i18n("<p><b>Camera Profile</b><p>"
                 "Select here the input color space used to decode RAW data.<p>"
@@ -492,12 +491,12 @@ void DcrawSettingsWidget::setup(int advSettings)
 
     d->outputColorSpaceLabel    = new QLabel(i18n("Workspace:"), d->colormanSettings);
     d->outputColorSpaceComboBox = new RComboBox( d->colormanSettings );
-    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::RAWCOLOR,       i18n("Raw (no profile)"));
-    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::SRGB,           i18n("sRGB"));
-    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::ADOBERGB,       i18n("Adobe RGB"));
-    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::WIDEGAMMUT,     i18n("Wide Gamut"));
-    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::PROPHOTO,       i18n("Pro-Photo"));
-    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::CUSTOMOUTPUTCS, i18n("Custom"));
+    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::RAWCOLOR,       i18nc("Workspace", "Raw (no profile)"));
+    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::SRGB,           i18nc("Workspace", "sRGB"));
+    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::ADOBERGB,       i18nc("Workspace", "Adobe RGB"));
+    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::WIDEGAMMUT,     i18nc("Workspace", "Wide Gamut"));
+    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::PROPHOTO,       i18nc("Workspace", "Pro-Photo"));
+    d->outputColorSpaceComboBox->insertItem(RawDecodingSettings::CUSTOMOUTPUTCS, i18nc("Workspace", "Custom"));
     d->outputColorSpaceComboBox->setDefaultIndex(RawDecodingSettings::SRGB);
     d->outputColorSpaceComboBox->setWhatsThis(i18n("<p><b>Workspace</b><p>"
                 "Select here the output color space used to decode RAW data.<p>"
@@ -530,19 +529,12 @@ void DcrawSettingsWidget::setup(int advSettings)
     colormanLayout->setSpacing(KDialog::spacingHint());
     colormanLayout->setMargin(KDialog::spacingHint());
 
-    insertItem(COLORMANAGEMENT, d->colormanSettings, i18n("Color Management"));
+    addItem(d->colormanSettings, SmallIcon("kdcraw"), i18n("Color Management"), QString("colormanagement"), false);
 
     if (! (advSettings & COLORSPACE))
-    {
-        removeItem(indexOf(d->colormanSettings));
-        d->colormanSettings->hide();
-        d->inputColorSpaceLabel->hide();
-        d->inputColorSpaceComboBox->hide();
-        d->inIccUrlEdit->hide();
-        d->outputColorSpaceLabel->hide();
-        d->outputColorSpaceComboBox->hide();
-        d->outIccUrlEdit->hide();
-    }
+        removeItem(COLORMANAGEMENT);
+
+    addStretch();
 
     // ---------------------------------------------------------------
 
@@ -608,6 +600,9 @@ void DcrawSettingsWidget::setup(int advSettings)
     connect(d->sixteenBitsImage, SIGNAL(toggled(bool)),
             this, SIGNAL(signalSettingsChanged()));
 
+    connect(d->fixColorsHighlights, SIGNAL(toggled(bool)),
+            this, SIGNAL(signalSettingsChanged()));
+
     connect(d->autoBrightnessBox, SIGNAL(toggled(bool)),
             this, SIGNAL(signalSettingsChanged()));
 
@@ -684,28 +679,9 @@ KUrlRequester* DcrawSettingsWidget::outputProfileUrlEdit() const
     return d->outIccUrlEdit;
 }
 
-void DcrawSettingsWidget::setDefaultSettings()
+void DcrawSettingsWidget::resetToDefault()
 {
-    setWhiteBalance((RawDecodingSettings::WhiteBalance)d->whiteBalanceComboBox->defaultIndex());
-    setCustomWhiteBalance(d->customWhiteBalanceSpinBox->defaultValue());
-    setCustomWhiteBalanceGreen(d->customWhiteBalanceGreenSpinBox->defaultValue());
-    setFourColor(false);
-    setUnclipColor(d->unclipColorComboBox->defaultIndex());
-    setDontStretchPixels(false);
-    setNoiseReduction(false);
-    setUseCACorrection(false);
-    setcaRedMultiplier(d->caRedMultSpinBox->defaultValue());
-    setcaBlueMultiplier(d->caBlueMultSpinBox->defaultValue());
-    setBrightness(d->brightnessSpinBox->defaultValue());
-    setUseBlackPoint(false);
-    setUseWhitePoint(false);
-    setBlackPoint(d->blackPointSpinBox->defaultValue());
-    setWhitePoint(d->whitePointSpinBox->defaultValue());
-    setNRThreshold(d->NRThresholdSpinBox->defaultValue());
-    setQuality((RawDecodingSettings::DecodingQuality)d->RAWQualityComboBox->defaultIndex());
-    setInputColorSpace((RawDecodingSettings::InputColorSpace)d->inputColorSpaceComboBox->defaultIndex());
-    setOutputColorSpace((RawDecodingSettings::OutputColorSpace)d->outputColorSpaceComboBox->defaultIndex());
-    setMedianFilterPasses(d->medianFilterPassesSpinBox->defaultValue());
+    setSettings(RawDecodingSettings());
 }
 
 void DcrawSettingsWidget::slotsixteenBitsImageToggled(bool b)
@@ -770,8 +746,6 @@ void DcrawSettingsWidget::slotOutputColorSpaceChanged(int item)
     d->outIccUrlEdit->setEnabled(item == RawDecodingSettings::CUSTOMOUTPUTCS);
 }
 
-// ---------------------------------------------------------------
-
 void DcrawSettingsWidget::setEnabledBrightnessSettings(bool b)
 {
     d->brightnessLabel->setEnabled(b);
@@ -783,42 +757,11 @@ bool DcrawSettingsWidget::brightnessSettingsIsEnabled()
     return d->brightnessSpinBox->isEnabled();
 }
 
-// ---------------------------------------------------------------
-
-bool DcrawSettingsWidget::sixteenBits()
+void DcrawSettingsWidget::setSettings(const RawDecodingSettings& settings)
 {
-    return d->sixteenBitsImage->isChecked();
-}
+    d->sixteenBitsImage->setChecked(settings.sixteenBitsImage);
 
-void DcrawSettingsWidget::setSixteenBits(bool b)
-{
-    d->sixteenBitsImage->setChecked(b);
-}
-
-// ---------------------------------------------------------------
-
-RawDecodingSettings::WhiteBalance DcrawSettingsWidget::whiteBalance()
-{
-    switch(d->whiteBalanceComboBox->currentIndex())
-    {
-        case 1:
-            return RawDecodingSettings::CAMERA;
-            break;
-        case 2:
-            return RawDecodingSettings::AUTO;
-            break;
-        case 3:
-            return RawDecodingSettings::CUSTOM;
-            break;
-        default:
-            return RawDecodingSettings::NONE;
-            break;
-    }
-}
-
-void DcrawSettingsWidget::setWhiteBalance(RawDecodingSettings::WhiteBalance v)
-{
-    switch(v)
+    switch(settings.whiteBalance)
     {
         case RawDecodingSettings::CAMERA:
             d->whiteBalanceComboBox->setCurrentIndex(1);
@@ -834,92 +777,15 @@ void DcrawSettingsWidget::setWhiteBalance(RawDecodingSettings::WhiteBalance v)
             break;
     }
     slotWhiteBalanceToggled(d->whiteBalanceComboBox->currentIndex());
-}
 
-// ---------------------------------------------------------------
+    d->medianFilterPassesSpinBox->setValue(settings.medianFilterPasses);
+    d->customWhiteBalanceSpinBox->setValue(settings.customWhiteBalance);
+    d->customWhiteBalanceGreenSpinBox->setValue(settings.customWhiteBalanceGreen);
+    d->fourColorCheckBox->setChecked(settings.RGBInterpolate4Colors);
+    d->autoBrightnessBox->setChecked(settings.autoBrightness);
+    d->fixColorsHighlights->setChecked(settings.fixColorsHighlights);
 
-int DcrawSettingsWidget::medianFilterPasses()
-{
-    return d->medianFilterPassesSpinBox->value();
-}
-
-void DcrawSettingsWidget::setMedianFilterPasses(int p)
-{
-    d->medianFilterPassesSpinBox->setValue(p);
-}
-
-// ---------------------------------------------------------------
-
-int DcrawSettingsWidget::customWhiteBalance()
-{
-    return d->customWhiteBalanceSpinBox->value();
-}
-
-void DcrawSettingsWidget::setCustomWhiteBalance(int v)
-{
-    d->customWhiteBalanceSpinBox->setValue(v);
-}
-
-// ---------------------------------------------------------------
-
-double DcrawSettingsWidget::customWhiteBalanceGreen()
-{
-    return d->customWhiteBalanceGreenSpinBox->value();
-}
-
-void DcrawSettingsWidget::setCustomWhiteBalanceGreen(double v)
-{
-    d->customWhiteBalanceGreenSpinBox->setValue(v);
-}
-
-// ---------------------------------------------------------------
-
-bool DcrawSettingsWidget::useFourColor()
-{
-    return d->fourColorCheckBox->isChecked();
-}
-
-void DcrawSettingsWidget::setFourColor(bool b)
-{
-    d->fourColorCheckBox->setChecked(b);
-}
-
-// ---------------------------------------------------------------
-
-bool DcrawSettingsWidget::useAutoBrightness()
-{
-    return d->autoBrightnessBox->isChecked();
-}
-
-void DcrawSettingsWidget::setAutoBrightness(bool b)
-{
-    d->autoBrightnessBox->setChecked(b);
-}
-
-// ---------------------------------------------------------------
-
-int DcrawSettingsWidget::unclipColor()
-{
-    switch(d->unclipColorComboBox->currentIndex())
-    {
-        case 0:
-            return 0;
-            break;
-        case 1:
-            return 1;
-            break;
-        case 2:
-            return 2;
-            break;
-        default:         // Reconstruct Highlight method
-            return d->reconstructSpinBox->value()+3;
-            break;
-    }
-}
-
-void DcrawSettingsWidget::setUnclipColor(int v)
-{
-    switch(v)
+    switch(settings.unclipColors)
     {
         case 0:
             d->unclipColorComboBox->setCurrentIndex(0);
@@ -932,111 +798,21 @@ void DcrawSettingsWidget::setUnclipColor(int v)
             break;
         default:         // Reconstruct Highlight method
             d->unclipColorComboBox->setCurrentIndex(3);
-            d->reconstructSpinBox->setValue(v-3);
+            d->reconstructSpinBox->setValue(settings.unclipColors-3);
             break;
     }
-
     slotUnclipColorActivated(d->unclipColorComboBox->currentIndex());
-}
 
-// ---------------------------------------------------------------
+    d->dontStretchPixelsCheckBox->setChecked(settings.DontStretchPixels);
+    d->brightnessSpinBox->setValue(settings.brightness);
+    d->blackPointCheckBox->setChecked(settings.enableBlackPoint);
+    d->blackPointSpinBox->setEnabled(settings.enableBlackPoint);
+    d->blackPointSpinBox->setValue(settings.blackPoint);
+    d->whitePointCheckBox->setChecked(settings.enableWhitePoint);
+    d->whitePointSpinBox->setEnabled(settings.enableWhitePoint);
+    d->whitePointSpinBox->setValue(settings.whitePoint);
 
-bool DcrawSettingsWidget::useDontStretchPixels()
-{
-    return d->dontStretchPixelsCheckBox->isChecked();
-}
-
-void DcrawSettingsWidget::setDontStretchPixels(bool b)
-{
-    d->dontStretchPixelsCheckBox->setChecked(b);
-}
-
-// ---------------------------------------------------------------
-
-double DcrawSettingsWidget::brightness()
-{
-    return d->brightnessSpinBox->value();
-}
-
-void DcrawSettingsWidget::setBrightness(double b)
-{
-    d->brightnessSpinBox->setValue(b);
-}
-
-// ---------------------------------------------------------------
-
-bool DcrawSettingsWidget::useBlackPoint()
-{
-    return d->blackPointCheckBox->isChecked();
-}
-
-void DcrawSettingsWidget::setUseBlackPoint(bool b)
-{
-    d->blackPointCheckBox->setChecked(b);
-    d->blackPointSpinBox->setEnabled(b);
-}
-
-// ---------------------------------------------------------------
-
-int DcrawSettingsWidget::blackPoint()
-{
-    return d->blackPointSpinBox->value();
-}
-
-void DcrawSettingsWidget::setBlackPoint(int b)
-{
-    d->blackPointSpinBox->setValue(b);
-}
-
-// ---------------------------------------------------------------
-
-bool DcrawSettingsWidget::useWhitePoint()
-{
-    return d->whitePointCheckBox->isChecked();
-}
-
-void DcrawSettingsWidget::setUseWhitePoint(bool b)
-{
-    d->whitePointCheckBox->setChecked(b);
-    d->whitePointSpinBox->setEnabled(b);
-}
-
-// ---------------------------------------------------------------
-
-int DcrawSettingsWidget::whitePoint()
-{
-    return d->whitePointSpinBox->value();
-}
-
-void DcrawSettingsWidget::setWhitePoint(int b)
-{
-    d->whitePointSpinBox->setValue(b);
-}
-
-// ---------------------------------------------------------------
-
-RawDecodingSettings::DecodingQuality DcrawSettingsWidget::quality()
-{
-    switch(d->RAWQualityComboBox->currentIndex())
-    {
-        case 1:
-            return RawDecodingSettings::VNG;
-            break;
-        case 2:
-            return RawDecodingSettings::PPG;
-            break;
-        case 3:
-            return RawDecodingSettings::AHD;
-            break;
-        default:
-            return RawDecodingSettings::BILINEAR;
-            break;
-    }
-}
-
-void DcrawSettingsWidget::setQuality(RawDecodingSettings::DecodingQuality q)
-{
-    switch(q)
+    switch(settings.RAWQuality)
     {
         case RawDecodingSettings::VNG:
             d->RAWQualityComboBox->setCurrentIndex(1);
@@ -1051,118 +827,115 @@ void DcrawSettingsWidget::setQuality(RawDecodingSettings::DecodingQuality q)
             d->RAWQualityComboBox->setCurrentIndex(0);
             break;
     }
+
+    d->inputColorSpaceComboBox->setCurrentIndex((int)settings.inputColorSpace);
+    slotInputColorSpaceChanged((int)settings.inputColorSpace);
+    d->outputColorSpaceComboBox->setCurrentIndex((int)settings.outputColorSpace);
+    slotOutputColorSpaceChanged((int)settings.outputColorSpace);
+    d->enableNoiseReduction->setChecked(settings.enableNoiseReduction);
+    slotNoiseReductionToggled(settings.enableNoiseReduction);
+    d->NRThresholdSpinBox->setValue(settings.NRThreshold);
+    d->enableCACorrection->setChecked(settings.enableCACorrection);
+    slotCACorrectionToggled(settings.enableCACorrection);
+    d->caRedMultSpinBox->setValue(settings.caMultiplier[0]);
+    d->caBlueMultSpinBox->setValue(settings.caMultiplier[1]);
+    d->inIccUrlEdit->setUrl(KUrl(settings.inputProfile));
+    d->outIccUrlEdit->setUrl(KUrl(settings.outputProfile));
 }
 
-// ---------------------------------------------------------------
-
-RawDecodingSettings::InputColorSpace DcrawSettingsWidget::inputColorSpace()
+RawDecodingSettings DcrawSettingsWidget::settings() const
 {
-    return (RawDecodingSettings::InputColorSpace)(d->inputColorSpaceComboBox->currentIndex());
+    RawDecodingSettings prm;
+    prm.sixteenBitsImage = d->sixteenBitsImage->isChecked();
+
+    switch(d->whiteBalanceComboBox->currentIndex())
+    {
+        case 1:
+            prm.whiteBalance = RawDecodingSettings::CAMERA;
+            break;
+        case 2:
+            prm.whiteBalance = RawDecodingSettings::AUTO;
+            break;
+        case 3:
+            prm.whiteBalance = RawDecodingSettings::CUSTOM;
+            break;
+        default:
+            prm.whiteBalance = RawDecodingSettings::NONE;
+            break;
+    }
+
+    prm.medianFilterPasses      = d->medianFilterPassesSpinBox->value();
+    prm.customWhiteBalance      = d->customWhiteBalanceSpinBox->value();
+    prm.customWhiteBalanceGreen = d->customWhiteBalanceGreenSpinBox->value();
+    prm.RGBInterpolate4Colors   = d->fourColorCheckBox->isChecked();
+    prm.autoBrightness          = d->autoBrightnessBox->isChecked();
+    prm.fixColorsHighlights     = d->fixColorsHighlights->isChecked();
+
+    switch(d->unclipColorComboBox->currentIndex())
+    {
+        case 0:
+            prm.unclipColors = 0;
+            break;
+        case 1:
+            prm.unclipColors = 1;
+            break;
+        case 2:
+            prm.unclipColors = 2;
+            break;
+        default:         // Reconstruct Highlight method
+            prm.unclipColors =  d->reconstructSpinBox->value()+3;
+            break;
+    }
+
+    prm.DontStretchPixels = d->dontStretchPixelsCheckBox->isChecked();
+    prm.brightness        = d->brightnessSpinBox->value();
+    prm.enableBlackPoint  = d->blackPointCheckBox->isChecked();
+    prm.blackPoint        = d->blackPointSpinBox->value();
+    prm.enableWhitePoint  = d->whitePointCheckBox->isChecked();
+    prm.whitePoint        = d->whitePointSpinBox->value();
+
+    switch(d->RAWQualityComboBox->currentIndex())
+    {
+        case 1:
+            prm.RAWQuality = RawDecodingSettings::VNG;
+            break;
+        case 2:
+            prm.RAWQuality = RawDecodingSettings::PPG;
+            break;
+        case 3:
+            prm.RAWQuality = RawDecodingSettings::AHD;
+            break;
+        default:
+            prm.RAWQuality = RawDecodingSettings::BILINEAR;
+            break;
+    }
+
+    prm.inputColorSpace      = (RawDecodingSettings::InputColorSpace)(d->inputColorSpaceComboBox->currentIndex());
+    prm.outputColorSpace     = (RawDecodingSettings::OutputColorSpace)(d->outputColorSpaceComboBox->currentIndex());
+    prm.enableNoiseReduction = d->enableNoiseReduction->isChecked();
+    prm.NRThreshold          = d->NRThresholdSpinBox->value();
+    prm.enableCACorrection   = d->enableCACorrection->isChecked();
+    prm.caMultiplier[0]      = d->caRedMultSpinBox->value();
+    prm.caMultiplier[1]      = d->caBlueMultSpinBox->value();
+    prm.inputProfile         = d->inIccUrlEdit->url().toLocalFile();
+    prm.outputProfile        = d->outIccUrlEdit->url().toLocalFile();
+
+    return prm;
 }
 
-void DcrawSettingsWidget::setInputColorSpace(RawDecodingSettings::InputColorSpace c)
+void DcrawSettingsWidget::writeSettings(KConfigGroup& group)
 {
-    d->inputColorSpaceComboBox->setCurrentIndex((int)c);
-    slotInputColorSpaceChanged((int)c);
+    RawDecodingSettings prm = settings();
+    prm.writeSettings(group);
+    RExpanderBox::writeSettings();
 }
 
-// ---------------------------------------------------------------
-
-RawDecodingSettings::OutputColorSpace DcrawSettingsWidget::outputColorSpace()
+void DcrawSettingsWidget::readSettings(KConfigGroup& group)
 {
-    return (RawDecodingSettings::OutputColorSpace)(d->outputColorSpaceComboBox->currentIndex());
-}
-
-void DcrawSettingsWidget::setOutputColorSpace(RawDecodingSettings::OutputColorSpace c)
-{
-    d->outputColorSpaceComboBox->setCurrentIndex((int)c);
-    slotOutputColorSpaceChanged((int)c);
-}
-
-// ---------------------------------------------------------------
-
-bool DcrawSettingsWidget::useNoiseReduction()
-{
-    return d->enableNoiseReduction->isChecked();
-}
-
-void DcrawSettingsWidget::setNoiseReduction(bool b)
-{
-    d->enableNoiseReduction->setChecked(b);
-    slotNoiseReductionToggled(b);
-}
-
-// ---------------------------------------------------------------
-
-int DcrawSettingsWidget::NRThreshold()
-{
-    return d->NRThresholdSpinBox->value();
-}
-
-void DcrawSettingsWidget::setNRThreshold(int b)
-{
-    d->NRThresholdSpinBox->setValue(b);
-}
-
-// ---------------------------------------------------------------
-
-bool DcrawSettingsWidget::useCACorrection()
-{
-    return d->enableCACorrection->isChecked();
-}
-
-void DcrawSettingsWidget::setUseCACorrection(bool b)
-{
-    d->enableCACorrection->setChecked(b);
-    slotCACorrectionToggled(b);
-}
-
-// ---------------------------------------------------------------
-
-double DcrawSettingsWidget::caRedMultiplier()
-{
-    return d->caRedMultSpinBox->value();
-}
-
-void DcrawSettingsWidget::setcaRedMultiplier(double b)
-{
-    d->caRedMultSpinBox->setValue(b);
-}
-
-// ---------------------------------------------------------------
-
-double DcrawSettingsWidget::caBlueMultiplier()
-{
-    return d->caBlueMultSpinBox->value();
-}
-
-void DcrawSettingsWidget::setcaBlueMultiplier(double b)
-{
-    d->caBlueMultSpinBox->setValue(b);
-}
-
-// ---------------------------------------------------------------
-
-QString DcrawSettingsWidget::inputColorProfile()
-{
-    return d->inIccUrlEdit->url().path();
-}
-
-void DcrawSettingsWidget::setInputColorProfile(const QString& path)
-{
-    d->inIccUrlEdit->setUrl(KUrl(path));
-}
-
-// ---------------------------------------------------------------
-
-QString DcrawSettingsWidget::outputColorProfile()
-{
-    return d->outIccUrlEdit->url().path();
-}
-
-void DcrawSettingsWidget::setOutputColorProfile(const QString& path)
-{
-    d->outIccUrlEdit->setUrl(KUrl(path));
+    RawDecodingSettings prm;
+    prm.readSettings(group);
+    setSettings(prm);
+    RExpanderBox::readSettings();
 }
 
 } // NameSpace KDcrawIface
