@@ -1,22 +1,26 @@
-/* ============================================================
+/** ===========================================================
+ * @file
  *
- * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * This file is a part of digiKam project
+ * <a href="http://www.digikam.org">http://www.digikam.org</a>
  *
- * Date        : 2007-09-03
- * Description : Exiv2 library interface for KDE
+ * @date   2007-09-03
+ * @brief  Exiv2 library interface for KDE
  *
- * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * @author Copyright (C) 2006-2010 by Gilles Caulier
+ *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
+ * @author Copyright (C) 2006-2010 by Marcel Wiesweg
+ *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
+ * either version 2, or (at your option)
+ * any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * ============================================================ */
@@ -124,7 +128,7 @@
 namespace KExiv2Iface
 {
 
-class KExiv2DataPriv : public QSharedData
+class KExiv2Data::KExiv2DataPriv : public QSharedData
 {
 public:
 
@@ -141,18 +145,27 @@ public:
 #endif
 };
 
-class KExiv2Priv
+class KExiv2::KExiv2Priv
 {
 public:
 
     KExiv2Priv();
     ~KExiv2Priv();
 
+    bool saveToXMPSidecar(const QFileInfo& finfo) const;
+    bool saveToFile(const QFileInfo& finfo) const;
+    bool saveOperations(Exiv2::Image::AutoPtr image) const;
+
     /** Generic method to print the Exiv2 C++ Exception error message from 'e'.
-        'msg' string is printed just before like debug header.
+        'msg' string is printed using kDebug rules..
     */
     static void printExiv2ExceptionError(const QString& msg, Exiv2::Error& e);
 
+    /** Generic method to print debug message from Exiv2.
+        'msg' string is printed using kDebug rules. 'lvl' is the debug level of Exiv2 message.
+    */
+    static void printExiv2MessageHandler(int lvl, const char* msg);
+
     /** Wrapper method to convert a Comments content to a QString.
     */
     QString convertCommentValue(const Exiv2::Exifdatum& exifDatum);
@@ -165,12 +178,12 @@ public:
      */
     int getXMPTagsListFromPrefix(const QString& pf, KExiv2::TagsMap& tagsMap);
 
-    const Exiv2::ExifData& exifMetadata() const { return data.constData()->exifMetadata;  }
-    const Exiv2::IptcData& iptcMetadata() const { return data.constData()->iptcMetadata;  }
-    const std::string& imageComments()    const { return data.constData()->imageComments; }
+    const Exiv2::ExifData& exifMetadata()  const { return data.constData()->exifMetadata;  }
+    const Exiv2::IptcData& iptcMetadata()  const { return data.constData()->iptcMetadata;  }
+    const std::string&     imageComments() const { return data.constData()->imageComments; }
 
 #ifdef _XMP_SUPPORT_
-    const Exiv2::XmpData&  xmpMetadata()  const { return data.constData()->xmpMetadata;   }
+    const Exiv2::XmpData&  xmpMetadata()   const { return data.constData()->xmpMetadata;   }
 #endif
 
     Exiv2::ExifData& exifMetadata() { return data.data()->exifMetadata;  }
@@ -183,14 +196,19 @@ public:
 
 public:
 
-    bool                               writeRawFiles;
-    bool                               updateFileTimeStamp;
+    bool                                           writeRawFiles;
+    bool                                           updateFileTimeStamp;
 
-    QString                            filePath;
-    QSize                              pixelSize;
-    QString                            mimeType;
+    bool                                           useXMPSidecar4Reading;
 
-    QSharedDataPointer<KExiv2DataPriv> data;
+    /// A mode from #MetadataWritingMode enum.
+    int                                            metadataWritingMode;         
+
+    QString                                        filePath;
+    QSize                                          pixelSize;
+    QString                                        mimeType;
+
+    QSharedDataPointer<KExiv2Data::KExiv2DataPriv> data;
 };
 
 }  // NameSpace KExiv2Iface
