@@ -83,6 +83,11 @@ KSaneWidgetPrivate::KSaneWidgetPrivate()
     m_previewHeight = 0;
     
     clearDeviceOptions();
+    
+    m_findDevThread = FindSaneDevicesThread::getInstance();
+    connect(m_findDevThread, SIGNAL(finished()), this, SLOT(devListUpdated()));
+    
+    m_auth = KSaneAuth::getInstance();
 }
 
 void KSaneWidgetPrivate::clearDeviceOptions()
@@ -131,6 +136,24 @@ void KSaneWidgetPrivate::clearDeviceOptions()
 
     delete m_scanThread;
     m_scanThread = 0;
+    
+    m_devName.clear();
+}
+
+void KSaneWidgetPrivate::devListUpdated()
+{
+    if (m_vendor.isEmpty()) {
+        const QList<KSaneWidget::DeviceInfo> list = m_findDevThread->devicesList();
+        if (list.size() == 0) return;
+        for (int i=0; i<list.size(); i++) {
+            kDebug() << list[i].name;
+            if (list[i].name == m_devName) {
+                m_vendor    = list[i].vendor;
+                m_model     = list[i].model;
+                break;
+            }
+        }
+    }
 }
 
 KSaneWidget::ImageFormat KSaneWidgetPrivate::getImgFormat(SANE_Parameters &params)
@@ -717,6 +740,7 @@ void KSaneWidgetPrivate::previewScanDone()
     if (m_closeDevicePending) {
         setBusy(false);
         sane_close(m_saneHandle);
+        m_saneHandle = 0;
         clearDeviceOptions();
         emit scanDone(KSaneWidget::NoError, "");
         return;
@@ -727,8 +751,13 @@ void KSaneWidgetPrivate::previewScanDone()
     if (m_optRes != 0) m_optRes->restoreSavedData();
     if (m_optResY != 0) m_optResY->restoreSavedData();
     if (m_optPreview != 0) m_optPreview->restoreSavedData();
-    
-    if (m_autoSelect) {
+
+    if ((m_previewThread->status != SANE_STATUS_GOOD) &&
+        (m_previewThread->status != SANE_STATUS_EOF))
+    {
+        KMessageBox::sorry(0, i18n(sane_strstatus(m_previewThread->status)));
+    }
+    else if (m_autoSelect) {
         m_previewViewer->findSelections();
     }
     
@@ -794,6 +823,7 @@ void KSaneWidgetPrivate::oneFinalScanDone()
     if (m_closeDevicePending) {
         setBusy(false);
         sane_close(m_saneHandle);
+        m_saneHandle = 0;
         clearDeviceOptions();
         return;
     }
