@@ -686,26 +686,6 @@ void PageViewAnnotator::setEnabled( bool on )
 
     // show the toolBar
     m_toolBar->showAndAnimate();
-
-    // ask for Author's name if not already set
-    if ( Okular::Settings::identityAuthor().isEmpty() )
-    {
-        // get default username from the kdelibs/kdecore/KUser
-        KUser currentUser;
-        QString userName = currentUser.property( KUser::FullName ).toString();
-        // ask the user for confirmation/change
-        bool firstTry = true;
-        while ( firstTry || userName.isEmpty()  )
-        {
-            QString prompt = firstTry ? i18n( "Please insert your name or initials:" ) :
-                i18n( "You must set this name:" );
-            userName = KInputDialog::getText( i18n("Annotations author"), prompt, userName );
-            firstTry = false;
-        }
-        // save the name
-        Okular::Settings::setIdentityAuthor( userName );
-        Okular::Settings::self()->writeConfig();
-    }
 }
 
 void PageViewAnnotator::setTextToolsEnabled( bool enabled )
@@ -731,20 +711,11 @@ QRect PageViewAnnotator::routeEvent( QMouseEvent * e, PageViewItem * item )
 {
     if ( !item ) return QRect();
 
-    // find out mouse event type
-    AnnotatorEngine::EventType eventType = AnnotatorEngine::Press;
-    if ( e->type() == QEvent::MouseMove )
-        eventType = AnnotatorEngine::Move;
-    else if ( e->type() == QEvent::MouseButtonRelease )
-        eventType = AnnotatorEngine::Release;
+    AnnotatorEngine::EventType eventType;
+    AnnotatorEngine::Button button;
 
-    // find out the pressed button
-    AnnotatorEngine::Button button = AnnotatorEngine::None;
-    Qt::MouseButtons buttonState = ( eventType == AnnotatorEngine::Move ) ? e->buttons() : e->button();
-    if ( buttonState == Qt::LeftButton )
-        button = AnnotatorEngine::Left;
-    else if ( buttonState == Qt::RightButton )
-        button = AnnotatorEngine::Right;
+    // figure out the event type and button
+    AnnotatorEngine::decodeEvent( e, &eventType, &button );
 
     // find out normalized mouse coords inside current item
     const QRect & itemRect = item->uncroppedGeometry();
@@ -911,7 +882,7 @@ void PageViewAnnotator::slotToolSelected( int toolID )
             {
                 QString tip = toolSubElement.text();
                 if ( !tip.isEmpty() )
-                    m_pageView->displayMessage( i18nc( "Annotation tool", tip.toUtf8() ), PageViewMessage::Annotation );
+                    m_pageView->displayMessage( i18nc( "Annotation tool", tip.toUtf8() ), QString(), PageViewMessage::Annotation );
             }
         }
 
